==> nextcloud-30.0.10.tgz: nextcloud/apps/comments/l10n/es_MX.js <==
OC.L10N.register(
    "comments",
    {
    "Comments" : "Comentarios",
    "You commented" : "Comentaste",
    "{author} commented" : "{author} comentó",
    "You commented on %1$s" : "Usted comentó en %1$s",
    "You commented on {file}" : "Hiciste un comentario de {file}",
    "%1$s commented on %2$s" : "%1$s comentó en %2$s",
    "{author} commented on {file}" : "{author} comentó en {file}",
    "<strong>Comments</strong> for files" : "<strong>Comentarios</strong> de los archivos",
    "Files" : "Archivo",
    "You were mentioned on \"{file}\", in a comment by an account that has since been deleted" : "Fue mencionado en \"{file}\", en un comentario realizado por un usuario que ha sido eliminado",
    "{user} mentioned you in a comment on \"{file}\"" : "{user} lo mencionó en un comentario en \"{file}\"",
    "Files app plugin to add comments to files" : "Un complemento a la aplicación de Archivos para agregar comentarios a los archivos",
    "Edit comment" : "Editar comentario",
    "Delete comment" : "Borrar comentario",
    "Cancel edit" : "Cancelar edición",
    "New comment" : "Nuevo comentario",
    "Write a comment …" : "Escribir un comentario …",
    "Post comment" : "Publicar comentario",
    "@ for mentions, : for emoji, / for smart picker" : "@ para menciones, : para emoticonos, / para selector inteligente",
    "Could not reload comments" : "No se pudieron recargar los comentarios",
    "Failed to mark comments as read" : "No se pudieron marcar los comentarios como leídos",
    "Unable to load the comments list" : "No se puede cargar la lista de comentarios",
    "No comments yet, start the conversation!" : "¡Aún no hay comentarios, inicia la conversación!",
    "No more messages" : "No hay más mensajes",
    "Retry" : "Reintentar",
    "_1 new comment_::_{unread} new comments_" : ["1 comentario nuevo","{unread} nuevos comentarios","{unread} nuevos comentarios"],
    "Comment" : "Comentario",
    "An error occurred while trying to edit the comment" : "Ocurrió un error al intentar editar el comentario",
    "Comment deleted" : "Comentario borrado",
    "An error occurred while trying to delete the comment" : "Ocurrió un error intentando borrar el comentario",
    "An error occurred while trying to create the comment" : "Ocurrió un error al intentar crear el comentario"
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");

==> nextcloud-31.0.11.tgz: nextcloud/apps/comments/l10n/es_MX.js <==
OC.L10N.register(
    "comments",
    {
    "Comments" : "Comentarios",
    "You commented" : "Comentaste",
    "{author} commented" : "{author} comentó",
    "You commented on %1$s" : "Usted comentó en %1$s",
    "You commented on {file}" : "Hiciste un comentario de {file}",
    "%1$s commented on %2$s" : "%1$s comentó en %2$s",
    "{author} commented on {file}" : "{author} comentó en {file}",
    "<strong>Comments</strong> for files" : "<strong>Comentarios</strong> de los archivos",
    "Files" : "Archivo",
    "You were mentioned on \"{file}\", in a comment by an account that has since been deleted" : "Fue mencionado en \"{file}\", en un comentario realizado por un usuario que ha sido eliminado",
    "{user} mentioned you in a comment on \"{file}\"" : "{user} lo mencionó en un comentario en \"{file}\"",
    "Files app plugin to add comments to files" : "Un complemento a la aplicación de Archivos para agregar comentarios a los archivos",
    "Edit comment" : "Editar comentario",
    "Delete comment" : "Borrar comentario",
    "Cancel edit" : "Cancelar edición",
    "New comment" : "Nuevo comentario",
    "Post comment" : "Publicar comentario",
    "@ for mentions, : for emoji, / for smart picker" : "@ para menciones, : para emoticonos, / para selector inteligente",
    "Could not reload comments" : "No se pudieron recargar los comentarios",
    "Failed to mark comments as read" : "No se pudieron marcar los comentarios como leídos",
    "Unable to load the comments list" : "No se puede cargar la lista de comentarios",
    "No comments yet, start the conversation!" : "¡Aún no hay comentarios, inicia la conversación!",
    "No more messages" : "No hay más mensajes",
    "Retry" : "Reintentar",
    "_1 new comment_::_{unread} new comments_" : ["1 comentario nuevo","{unread} nuevos comentarios","{unread} nuevos comentarios"],
    "Comment" : "Comentario",
    "An error occurred while trying to edit the comment" : "Ocurrió un error al intentar editar el comentario",
    "Comment deleted" : "Comentario borrado",
    "An error occurred while trying to delete the comment" : "Ocurrió un error intentando borrar el comentario",
    "An error occurred while trying to create the comment" : "Ocurrió un error al intentar crear el comentario",
    "Write a comment …" : "Escribir un comentario …"
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
